@@ -1200,7 +1200,7 @@ class ModelExecution(BaseModel):
                 "COMPUTED_BATCH_DATA",
                 "BATCH_TIME_DATA",
                 "BATCH_TAG_KEY",
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
                 "STORED_BATCH_VECTOR_DATA",
             ]
         elif data_type == "any" and values_type == "scalar":
@@ -1215,14 +1215,14 @@ class ModelExecution(BaseModel):
             ]
         elif data_type == "any" and values_type == "vector":
             input_types = [
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
                 "STORED_BATCH_VECTOR_DATA",
             ]
         elif data_type == "time" and values_type == "any":
             input_types = [
                 "STORED_CONTINUOUS_DATA",
                 "COMPUTED_CONTINUOUS_DATA",
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
             ]
             if strict is False:
                 input_types.append("DATA")
@@ -1234,7 +1234,7 @@ class ModelExecution(BaseModel):
             if strict is False:
                 input_types.append("DATA")
         elif data_type == "time" and values_type == "vector":
-            input_types = ["STORED_TIME_VECTOR_DATA"]
+            input_types = ["STORED_CONTINUOUS_VECTOR_DATA"]
             if strict is False:
                 input_types.append("VECTOR_DATA")
         elif data_type == "batch" and values_type == "any":
@@ -1296,7 +1296,7 @@ class ModelExecution(BaseModel):
                 "BATCH_TIME_DATA",
                 "BATCH_TAG_KEY",
                 "STORED_BATCH_VECTOR_DATA",
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
             ]
         elif data_type == "any" and values_type == "scalar":
             output_types = [
@@ -1310,14 +1310,14 @@ class ModelExecution(BaseModel):
             ]
         elif data_type == "any" and values_type == "vector":
             output_types = [
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
                 "STORED_BATCH_VECTOR_DATA",
             ]
         elif data_type == "time" and values_type == "any":
             output_types = [
                 "STORED_CONTINUOUS_DATA",
                 "COMPUTED_CONTINUOUS_DATA",
-                "STORED_TIME_VECTOR_DATA",
+                "STORED_CONTINUOUS_VECTOR_DATA",
             ]
             if strict is False:
                 output_types.append("DATA")
@@ -1326,7 +1326,7 @@ class ModelExecution(BaseModel):
             if strict is False:
                 output_types.append("DATA")
         elif data_type == "time" and values_type == "vector":
-            output_types = ["STORED_TIME_VECTOR_DATA"]
+            output_types = ["STORED_CONTINUOUS_VECTOR_DATA"]
             if strict is False:
                 output_types.append("VECTOR_DATA")
         elif data_type == "batch" and values_type == "any":
@@ -1407,18 +1407,30 @@ def get_default_model_execution():
 DEFAULT_EXECUTION_REPORT: Optional[ExecutionReport] = None
 
 
-def set_default_execution_report(output_summary: ExecutionReport):
+def set_default_execution_report(execution_report: ExecutionReport):
     """
-    Put a summary into a global variable, for external use
+    Put an execution report into a global variable, for external use
+
     Parameters
     ----------
-    output_summary: OutputSummary
+    execution_report: ExecutionReport
     """
 
     global DEFAULT_EXECUTION_REPORT
-    DEFAULT_EXECUTION_REPORT = output_summary
+    DEFAULT_EXECUTION_REPORT = execution_report
 
 
 def get_default_execution_report():
+    """
+    Get the current default execution report.
+    If none has been set yet, it creates an empty one.
+
+    Returns
+    -------
+    The current default execution report
+    """
+
     global DEFAULT_EXECUTION_REPORT
+    if DEFAULT_EXECUTION_REPORT is None:
+        DEFAULT_EXECUTION_REPORT = ExecutionReport(testMode=True)
     return DEFAULT_EXECUTION_REPORT
