@@ -1,8 +1,10 @@
 from .single_observation import get_single_obs_time_data, get_single_obs_batch_data
 from .files import get_resource_file
+from .instances import invoke_instance
 
 __all__ = [
     "get_single_obs_time_data",
     "get_single_obs_batch_data",
     "get_resource_file",
+    "invoke_instance",
 ]
