@@ -23,10 +23,7 @@ def get_resource_file(
 
     # Query endpoint
     url = f"{api_credentials.base_url}/api/oianalytics/python-model-instances/{model_instance_id}/resources/{resource_file_id}/content"
-    response = requests.get(
-        url=url,
-        **api_credentials.auth_kwargs,
-    )
+    response = requests.get(url=url, **api_credentials.auth_kwargs,)
 
     # Output
     response.raise_for_status()
