@@ -115,6 +115,8 @@ class TimeValuesOutput:
                         data_type="any", values_type="scalar", mode="object"
                     ).values()
                 }
+            else:
+                self.units = units
         else:
             self.units = units
 
@@ -187,6 +189,8 @@ class VectorTimeValuesOutput:
                     ).values()
                     if output_data.reference in data_reference
                 }
+            else:
+                self.values_units = values_units
         else:
             self.values_units = values_units
 
@@ -201,6 +205,8 @@ class VectorTimeValuesOutput:
                     ).values()
                     if output_data.reference in data_reference
                 }
+            else:
+                self.index_units = index_units
         else:
             self.index_units = index_units
 
