@@ -1,4 +1,4 @@
-from typing import Optional, Union, List
+from typing import Optional, Union, List, Any
 from datetime import datetime, timedelta, timezone
 import dateutil
 
@@ -18,12 +18,50 @@ class TestModelExecution(_dtos.ModelExecution):
         - timedelta(hours=1),
         current_execution_instant: datetime = datetime.now(timezone.utc),
         data_exchange_mode: str = "FREE_FROM_API",
+        execution_context_initiator: str = "TRIGGER",
         single_observation_type: str = "time",
         single_observation_overlapping_period: timedelta = timedelta(hours=1),
         single_observation_aggregation_period: str = "PT10M",
         single_observation_batch_type_id: str = "single_obs_batch_type_id",
         single_observation_batch_type_reference: str = "single_obs_batch_type_reference",
+        trigger_type: str = "cron-trigger",
+        upload_event_id: Optional[str] = None,
+        file_name: Optional[str] = None,
+        custom_data: Optional[Any] = None,
     ):
+        """
+
+        Parameters
+        ----------
+        test_mode: bool, default True
+            Whether the execution is a test, in which case the outputs are not sent to OIA
+        last_successful_execution_instant: datetime, default 1 hour ago
+            Exactly time when the model was last executed
+        current_execution_instant: datetime, default time now
+            Exactly time when the current model execution was launched
+        data_exchange_mode: {'SINGLE_OBSERVATION', 'FREE_FROM_API', 'FILE_PROCESSING'}, default 'FREE_FROM_API'
+            Data exchange mode of the model
+        execution_context_initiator: {'TRIGGER', 'MANUAL'}
+            How the model execution is activated
+        single_observation_type: {'time', 'batch'}, default 'time'
+            Characteristic of the data being used for the model; required only if 'data_exchange_mode' is 'SINGLE_OBSERVATION'
+        single_observation_overlapping_period: timedelta, default 1 hour
+            Definition of how long before the 'current_execution_instant' the input data should be included from; required only if 'data_exchange_mode' is 'SINGLE_OBSERVATION'
+        single_observation_aggregation_period: str, optional
+            Time interval over which an aggregation function is applied; required only if 'data_exchange_mode' is 'SINGLE_OBSERVATION'
+        single_observation_batch_type_id: str, optional
+            Unique identifier of the batch; required only for batch data
+        single_observation_batch_type_reference: str, optional
+            Reference of the batch type; required only for batch data and if 'data_exchange_mode' is 'SINGLE_OBSERVATION'
+        trigger_type: {'cron-trigger', 'file-reception', 'manual-only'}; default 'cron-trigger'
+            The type of trigger that activates the model execution
+        upload_event_id: str, default None
+            Unique identifier of the upload event; required only if 'execution_context_type' is 'file'
+        file_name: str, default None
+            Name of the file; required only if 'trigger_type' is 'file-reception'
+        custom_data: Any, default None
+            Customised input data
+        """
         # Data exchange mode
         if data_exchange_mode == "FREE_FROM_API":
             single_obs_context = None
@@ -52,6 +90,8 @@ class TestModelExecution(_dtos.ModelExecution):
                 raise ValueError(
                     f"{single_observation_type} is not valid for 'single_observation_type'"
                 )
+        elif data_exchange_mode == "FILE_PROCESSING":
+            single_obs_context = None
         else:
             raise ValueError(
                 f"{data_exchange_mode} is not valid for 'data_exchange_mode'"
@@ -67,15 +107,42 @@ class TestModelExecution(_dtos.ModelExecution):
         else:
             current_execution = current_execution_instant
 
+        if trigger_type == "cron-trigger":
+            trigger = _dtos.CronTrigger(type="cron-trigger", cron="0 0 * * * *")
+            execution_context_type = "time"
+        elif trigger_type == "file-reception":
+            trigger = _dtos.FileReceptionTrigger(type="file-reception")
+            execution_context_type = "file"
+            if upload_event_id is None:
+                upload_event_id = "upload_event_id"
+            if file_name is None:
+                file_name = "filename.csv"
+        elif trigger_type == "manual-only":
+            trigger = _dtos.ManualOnlyTrigger(type="manual-only")
+            execution_context_type = "manual"
+        else:
+            raise ValueError(
+                f"{trigger_type} is not valid for 'trigger_type'"
+            )
+
         # Init
         super().__init__(
             testMode=test_mode,
             credentials=None,
             lastSuccessfulExecutionInstant=last_execution.astimezone(timezone.utc),
             currentExecutionInstant=current_execution.astimezone(timezone.utc),
+            executionContext=_dtos.ExecutionContext(
+                type=execution_context_type,
+                initiator=execution_context_initiator,
+                lastSuccessfulExecutionInstant=last_execution.astimezone(timezone.utc),
+                currentExecutionInstant=current_execution.astimezone(timezone.utc),
+                customData=custom_data,
+                uploadEventId=upload_event_id,
+                fileName=file_name,
+            ),
             pythonModelInstance=_dtos.ModelInstance(
                 id="test_instance_id",
-                trigger=_dtos.CronTrigger(type="cron-trigger", cron="0 0 * * * *"),
+                trigger=trigger,
                 active=False,
                 dataExchangeMode=data_exchange_mode,
                 singleObservationContext=single_obs_context,
@@ -98,6 +165,9 @@ class TestModelExecution(_dtos.ModelExecution):
         test_model_execution.pythonModelInstance = model_execution.pythonModelInstance
         return test_model_execution
 
+    def set_custom_input_data(self, custom_data: Any):
+        self.executionContext.customData = custom_data
+
     def add_single_observation_feature_filter(
         self,
         feature_id: str = "single_obs_feature_id",
@@ -141,9 +211,7 @@ class TestModelExecution(_dtos.ModelExecution):
         )
 
     def add_file_input(
-        self,
-        source_code_name: str = "file_input",
-        value: Optional[str] = "file_id",
+        self, source_code_name: str = "file_input", value: Optional[str] = "file_id",
     ):
         self.pythonModelInstance.inputParameters.append(
             _dtos.FileParameter(
@@ -152,9 +220,7 @@ class TestModelExecution(_dtos.ModelExecution):
         )
 
     def add_period_input(
-        self,
-        source_code_name: str = "period_input",
-        value: Optional[str] = "PT12H",
+        self, source_code_name: str = "period_input", value: Optional[str] = "PT12H",
     ):
         self.pythonModelInstance.inputParameters.append(
             _dtos.PeriodParameter(
@@ -239,9 +305,7 @@ class TestModelExecution(_dtos.ModelExecution):
 
         self.pythonModelInstance.inputParameters.append(
             _dtos.TagKeyParameter(
-                type="TAG_KEY",
-                sourceCodeName=source_code_name,
-                value=tagkey_value,
+                type="TAG_KEY", sourceCodeName=source_code_name, value=tagkey_value,
             )
         )
 
@@ -260,9 +324,7 @@ class TestModelExecution(_dtos.ModelExecution):
 
         self.pythonModelInstance.inputParameters.append(
             _dtos.TagValueParameter(
-                type="TAG_VALUE",
-                sourceCodeName=source_code_name,
-                value=tagvalue_value,
+                type="TAG_VALUE", sourceCodeName=source_code_name, value=tagvalue_value,
             )
         )
 
@@ -290,9 +352,7 @@ class TestModelExecution(_dtos.ModelExecution):
 
         self.pythonModelInstance.inputParameters.append(
             _dtos.DataParameter(
-                type="DATA",
-                sourceCodeName=source_code_name,
-                value=data_value,
+                type="DATA", sourceCodeName=source_code_name, value=data_value,
             )
         )
 
@@ -325,6 +385,38 @@ class TestModelExecution(_dtos.ModelExecution):
             )
         )
 
+    def add_vector_timedata_input(
+        self,
+        source_code_name: str = "vector_timedata_input",
+        data_id: Optional[str] = "vector_timedata_id",
+        data_reference: str = "vector_timedata_reference",
+        value_unit_id: str = "value_unit_id",
+        index_unit_id: str = "index_unit_id",
+        value_unit_label: str = "Unit label",
+        index_unit_label: str = "Index unit label",
+        aggregation_function: Optional[str] = None,
+    ):
+        if data_id is None:
+            data_value = None
+        else:
+            data_value = _dtos.VectorDataValue(
+                type="data",
+                id=data_id,
+                reference=data_reference,
+                dataType="STORED_CONTINUOUS_VECTOR_DATA",
+                valueUnit=_dtos.DataUnit(id=value_unit_id, label=value_unit_label),
+                indexUnit=_dtos.DataUnit(id=index_unit_id, label=index_unit_label),
+                aggregationFunction=aggregation_function,
+            )
+
+        self.pythonModelInstance.inputParameters.append(
+            _dtos.StoredTimeVectorDataParameter(
+                type="STORED_CONTINUOUS_VECTOR_DATA",
+                sourceCodeName=source_code_name,
+                value=data_value,
+            )
+        )
+
     def add_batchdata_input(
         self,
         source_code_name: str = "batchdata_input",
@@ -357,6 +449,41 @@ class TestModelExecution(_dtos.ModelExecution):
             )
         )
 
+    def add_vector_batchdata_input(
+        self,
+        source_code_name: str = "batch_vector_data_input",
+        data_id: Optional[str] = "batch_vector_data_id",
+        data_reference: str = "batch_vector_data_reference",
+        value_unit_id: str = "unit_id",
+        value_unit_label: str = "Unit label",
+        index_unit_id: str = "index_unit_id",
+        index_unit_label: str = "Index unit label",
+        aggregation_function: Optional[str] = None,
+        batch_type_id: str = "batch_type_id",
+        batch_type_name: str = "Batch type name",
+    ):
+        if data_id is None:
+            data_value = None
+        else:
+            data_value = _dtos.BatchVectorDataValue(
+                type="batch-data",
+                id=data_id,
+                reference=data_reference,
+                dataType="STORED_BATCH_VECTOR_DATA",
+                valueUnit=_dtos.DataUnit(id=value_unit_id, label=value_unit_label),
+                indexUnit=_dtos.DataUnit(id=index_unit_id, label=index_unit_label),
+                aggregationFunction=aggregation_function,
+                batchType=_dtos.BatchType(id=batch_type_id, name=batch_type_name),
+            )
+
+        self.pythonModelInstance.inputParameters.append(
+            _dtos.StoredBatchVectorDataParameter(
+                type="STORED_BATCH_VECTOR_DATA",
+                sourceCodeName=source_code_name,
+                value=data_value,
+            )
+        )
+
     def add_computed_timedata_input(
         self,
         source_code_name: str = "computed_timedata_input",
@@ -481,18 +608,14 @@ class TestModelExecution(_dtos.ModelExecution):
             elif feature_value_ids is not None:
                 feature_filters = [
                     _dtos.BatchTagValue(
-                        type="batch-tag-value",
-                        id=fid,
-                        reference=f"{fid}_reference",
+                        type="batch-tag-value", id=fid, reference=f"{fid}_reference",
                     )
                     for fid in feature_value_ids
                 ]
             else:
                 feature_filters = [
                     _dtos.BatchTagValue(
-                        type="batch-tag-value",
-                        id=f"{fref}_id",
-                        reference=fref,
+                        type="batch-tag-value", id=f"{fref}_id", reference=fref,
                     )
                     for fref in feature_value_references
                 ]
@@ -501,9 +624,7 @@ class TestModelExecution(_dtos.ModelExecution):
             batch_predicate_value = _dtos.BatchPredicateValue(
                 type="batch-predicate",
                 batchType=_dtos.BatchPredicateBatchType(
-                    type="batch-type",
-                    id=batch_type_id,
-                    reference=batch_type_reference,
+                    type="batch-type", id=batch_type_id, reference=batch_type_reference,
                 ),
                 featureFilters=feature_filters,
             )
@@ -666,8 +787,37 @@ class TestModelExecution(_dtos.ModelExecution):
 
         self.pythonModelInstance.outputParameters.append(
             _dtos.DataParameter(
-                type="DATA",
-                sourceCodeName=source_code_name,
-                value=data_value,
+                type="DATA", sourceCodeName=source_code_name, value=data_value,
+            )
+        )
+
+    def add_vector_data_output(
+        self,
+        source_code_name: str = "vector_data_output",
+        data_id: Optional[str] = "data_id",
+        data_reference: str = "data_reference",
+        data_type: str = "STORED_CONTINUOUS_VECTOR_DATA",
+        value_unit_id: str = "value_unit_id",
+        value_unit_label: str = "Value unit label",
+        index_unit_id: str = "index_unit_id",
+        index_unit_label: str = "Index unit label",
+        aggregation_function: Optional[str] = None,
+    ):
+        if data_id is None:
+            data_value = None
+        else:
+            data_value = _dtos.VectorDataValue(
+                type="data",
+                id=data_id,
+                reference=data_reference,
+                dataType=data_type,
+                valueUnit=_dtos.DataUnit(id=value_unit_id, label=value_unit_label),
+                indexUnit=_dtos.DataUnit(id=index_unit_id, label=index_unit_label),
+                aggregationFunction=aggregation_function,
+            )
+
+        self.pythonModelInstance.outputParameters.append(
+            _dtos.VectorDataParameter(
+                type="VECTOR_DATA", sourceCodeName=source_code_name, value=data_value,
             )
         )
