@@ -54,6 +54,12 @@ def test_process_data(
             outputs.OIModelOutputs,
             outputs.FileOutput,
             outputs.TimeValuesOutput,
+            outputs.VectorTimeValuesOutput,
+            outputs.BatchValuesOutput,
+            outputs.VectorBatchValuesOutput,
+            outputs.BatchFeaturesOutput,
+            outputs.CustomJsonOutput,
+            outputs.CustomTextOutput,
             outputs.Delay,
         ),
     ):
@@ -74,28 +80,16 @@ def test_full_model(
     if model_execution is None:
         model_execution = _dtos.get_default_model_execution()
 
-    # Run load_data function
-    data = load_data(**model_execution.execution_kwargs)
-
     # Run load_resources function
     resources = load_resources(**model_execution.execution_kwargs)
 
     # Run load_data function
-    model_output = process_data(
-        data=data, resources=resources, **model_execution.execution_kwargs
+    data = load_data(resources=resources, **model_execution.execution_kwargs)
+
+    model_output = test_process_data(
+        process_data=process_data,
+        data=data,
+        resources=resources,
     )
 
-    if not isinstance(
-        model_output,
-        (
-            outputs.OIModelOutputs,
-            outputs.FileOutput,
-            outputs.TimeValuesOutput,
-            outputs.Delay,
-        ),
-    ):
-        print(
-            "Warning: the model output should be an instance of an output class from oianalytics.models.outputs"
-        )
-
     return model_output
